@@ -25,7 +25,7 @@ class Option(object):
 
     @property
     def name(self):
-        return self._name
+        return self._name.replace('_', '')
 
     @name.setter
     def name(self, name):
@@ -134,11 +134,11 @@ class StringOption(FileOption):
         Args:
             name: Option name (e.g.: aa)
             description: Longer description for Radiance option (e.g. ambient accuracy).
-            value: Optional value for aa (Default: None).
+            value: Optional value for the option (Default: None).
             valid_values: An optional list of valid values. By default all the string
                 values are valid.
             whole: Set to true if the whole input string should be compared against valid
-                values. If set to False the validator will run for each charecter in
+                values. If set to False the validator will run for each character in
                 input string.
             pattern_in: A regex pattern that input values should match (Default: None).
             pattern_out: A format pattern to be applied to value for output e.g. "'%s'"
@@ -507,3 +507,33 @@ class OptionCollection(object):
         check to ensure this is always correct.
         """
         pass
+
+
+class ToggleOption(Option):
+    """Toggle radiance option."""
+
+    __slots__ = ()
+
+    @property
+    def value(self):
+        """Toggle value."""
+        return self._value
+
+    @value.setter
+    def value(self, val):
+        if not val:
+            self._value = None
+        elif val in ('+', '-'):
+            if val == '+':
+                self._value = '+'
+            else:
+                self._value = '-'
+        else:
+            raise ValueError("The value needs to be either '+' or '-' only.")
+
+    def to_radiance(self):
+        """Translate option to Radiance format."""
+        if self.value is not None:
+            return '%s%s' % (self.value, self.name)
+        else:
+            return ''
